@@ -21,10 +21,13 @@ def is_valid_increment_version(increment_version):
         return True
     return False
 
+
 def is_valid_version(version):
-    pattern = re.compile(r"^([0-9]+)\.([0-9]+)\.([0-9]+)(?:-([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?(?:\+[0-9A-Za-z-]+)?$")
+    pattern = re.compile(
+        r"^([0-9]+)\.([0-9]+)\.([0-9]+)(?:-([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?(?:\+[0-9A-Za-z-]+)?$"
+    )
     return True if version and pattern.match(version) else False
-        
+
 
 def write_zip(zip, fp, root, name):
     path = os.path.abspath(os.path.join(root, name))
@@ -35,7 +38,7 @@ def write_zip(zip, fp, root, name):
         zip.write(path, os.path.basename(path))
 
 
-def do_pack(fp, src, target, ignore_paths=None):
+def package_directory(fp, src, target, ignore_paths=None):
     ignore_paths = [] if not ignore_paths else ignore_paths
 
     with zipfile.ZipFile(target, "w", zipfile.ZIP_STORED) as zip:
@@ -68,7 +71,7 @@ def package(args):
     if increment_version and not version:
         if not is_valid_increment_version(increment_version):
             raise SystemExit(INVALID_VERSION_ARGUMENT)
-        manifest_file.increment_version(increment_version)
+        version = manifest_file.increment_version(increment_version)
 
     elif version and not increment_version:
         if not is_valid_version(version):
@@ -87,9 +90,9 @@ def package(args):
             for name in glob(os.path.join(filepath, src, pattern))
         ]
 
-        do_pack(
+        package_directory(
             filepath,
             os.path.join(filepath, src),
-            os.path.join(dist, f"{finder.name}.zip"),
+            os.path.join(dist, f"{finder.name}-{version}.zip"),
             ignore_paths,
         )
